searchNodes=[{"ref":"Raxx.View.html","title":"Raxx.View","type":"module","doc":"Generate views from .eex template files. Using this module will add the functions html and render to a module. To create layouts that can be reused across multiple pages check out Raxx.View.Layout. Example # greet.html.eex &lt;p&gt;Hello, &lt;%= name %&gt;&lt;/p&gt; # layout.html.eex &lt;h1&gt;Greetings&lt;/h1&gt; &lt;%= __content__ %&gt; # greet.ex defmodule Greet do use Raxx.View, arguments: [:name], layout: &quot;layout.html.eex&quot; end # iex -S mix Greet.html(&quot;Alice&quot;) # =&gt; &quot;&lt;h1&gt;Greetings&lt;/h1&gt;\\n&lt;p&gt;Hello, Alice&lt;/p&gt;&quot; Raxx.response(:ok) |&gt; Greet.render(&quot;Bob&quot;) # =&gt; %Raxx.Response{ # status: 200, # headers: [{&quot;content-type&quot;, &quot;text/html&quot;}], # body: &quot;&lt;h1&gt;Greetings&lt;/h1&gt;\\n&lt;p&gt;Hello, Bob&lt;/p&gt;&quot; # } Options arguments: A list of atoms for variables used in the template. This will be the argument list for the html function. The render function takes one additional argument to this list, a response struct. template (optional): The eex file containing a main content template. If not given the template file will be generated from the file of the calling module. i.e. path/to/file.ex -&gt; path/to/file.html.eex layout (optional): An eex file containing a layout template. This template can use all the same variables as the main template. In addition it must include the content using &lt;%= __content__ %&gt; Safety XSS (Cross Site Scripting) Prevention All content interpolated into a view is escaped. iex&gt; Greet.html(&quot;&lt;script&gt;&quot;) # =&gt; &quot;&lt;h1&gt;Greetings&lt;/h1&gt;\\n&lt;p&gt;Hello, &amp;lt;script&amp;gt;&lt;/p&gt;&quot; Values in the template can be marked as secure using the EExHTML.raw/1 function. raw is automatically imported to the template scope. # greet.html.eex &lt;p&gt;Hello, &lt;%= raw name %&gt;&lt;/p&gt; JavaScript Including untrusted data inside any other JavaScript context is quite dangerous, as it is extremely easy to switch into an execution context with characters including (but not limited to) semi-colon, equals, space, plus, and many more, so use with caution. XSS Prevention Cheat Sheet DONT DO THIS &lt;script type=&quot;text/javascript&quot;&gt; console.log(&#39;Hello, &#39; + &lt;%= name %&gt;) &lt;/script&gt; Use javascript_variables/1 for injecting variables into any JavaScript environment."},{"ref":"Raxx.View.html#partial/3","title":"Raxx.View.partial/3","type":"macro","doc":"Generate template partials from eex templates."},{"ref":"Raxx.View.Layout.html","title":"Raxx.View.Layout","type":"module","doc":"Create a general template that can be reused by views. Using this module will create a module that can be used as a view. All functions created in the layout module will be available in the layout template and the content template Example Creating a new layout # www/layout.html.eex &lt;h1&gt;My Site&lt;/h1&gt; &lt;%= __content__ %&gt; # www/layout.ex defmodule WWW.Layout do use Raxx.View.Layout, layout: &quot;layout.html.eex&quot; def format_datetime(datetime) do DateTime.to_iso8601(datetime) end end Creating a view # www/show_user.html.eex &lt;h2&gt;&lt;%= user.username %&gt;&lt;/h2&gt; &lt;p&gt;signed up at &lt;%= format_datetime(user.interted_at) %&gt;&lt;/p&gt; # www/show_user.ex defmodule WWW.ShowUser do use Raxx.SimpleServer use WWW.Layout, template: &quot;show_user.html.eex&quot;, arguments: [:user] @impl Raxx.Server def handle_request(_request, _state) do user = # fetch user somehow response(:ok) |&gt; render(user) end end Options layout (optional): The eex file containing the layout template. If not given the template file will be generated from the file of the calling module. i.e. path/to/file.ex -&gt; path/to/file.html.eex imports (optional): A list of modules to import into the template. The default behaviour is to import only the layout module into each view. Set this option to false to import no functions."},{"ref":"readme.html","title":"Raxx.View","type":"extras","doc":"Raxx.View Generate HTML views from .eex template files for Raxx web applications. Install from hex.pm Documentation available on hexdoc Discuss on slack Defining Views Common layout to use in multiple views. lib/my_app/layout.html.eex &lt;header&gt; &lt;h1&gt;&lt;% title %&gt;&lt;/h1&gt; &lt;%= __content__ %&gt; &lt;/header&gt; Template to show a list of users. lib/my_app/list_users.html.eex &lt;%= for user &lt;- users do %&gt; &lt;section&gt; &lt;a href=&quot;/users/&lt;%= user.id %&gt;&quot;&gt;&lt;%= user.name %&gt;&lt;/a&gt; &lt;p&gt; Joined on &lt;%= Timex.format!(user.registered_at, &quot;{YYYY}-0{M}-0{D}&quot;) %&gt; &lt;/p&gt; &lt;/section&gt; View module that uses our templates. lib/my_app/list_users_view.ex defmodule MyApp.ListUsersView do use Raxx.View, arguments: [:users], optional: [title: &quot;My App&quot;] template: &quot;list_users.html.eex&quot;, layout: &quot;layout.html.eex&quot; end variables set in :optional have a default value that can be overwritten when using the view. If :template is left unspecified the view will assume the template is in a file of the same name but with extension .html.eex in place of .ex or .exs. An option for :layout can be omitted if all the content is in the view. The :arguments can be set to [:assigns] if you prefer to use @var in you eex templates. This will not give you a compile time waring about unused arguments. Using views The Raxx.View macro generates a render function for adding a view to a request/response. response = Raxx.response(:ok) MyApp.ListUsersView.render(response, user, title: &quot;Users Page&quot;) To work directly with the generated string an html function is also generated. MyApp.ListUsersView.html(user, title: &quot;Users Page&quot;) Views in controllers/actions For simple usecases it is often more convenient to keep the controller and view code together. defmodule MyApp.ListUsers do use Raxx.SimpleServer use Raxx.View, arguments: [:users], optional: [title: &quot;My App&quot;] template: &quot;list_users.html.eex&quot;, layout: &quot;layout.html.eex&quot; @impl Raxx.SimpleServer def handle_request(_request, _state) do users = MyApp.fetch_users() response(:ok) |&gt; render(users) end end Helpers Helpers can be used to limit the amount of code written in a template. Functions defined in a view module, public or private, can be called in the template. lib/my_app/list_users.ex # ... rest of module def display_date(datetime = %DateTime{}) do Timex.format!(datetime, &quot;{YYYY}-0{M}-0{D}&quot;) end def user_page_link(user) do ~E&quot;&quot;&quot; &lt;a href=&quot;/users/&lt;%= user.id %&gt;&quot;&gt;&lt;%= user.name %&gt;&lt;/a&gt; &quot;&quot;&quot; end Update the template to use the helpers. lib/my_app/list_users.html.eex &lt;%= for user &lt;- users do %&gt; &lt;section&gt; user_page_link(user) &lt;p&gt; Joined on &lt;%= display_date(user.registered_at) %&gt; &lt;/p&gt; &lt;/section&gt; Partials A partial is like any another helper function, but one that uses an EEx template file. lib/my_app/list_users.ex # ... rest of module partial(:profile_card, [:user], template: &quot;profile_card.html.eex&quot;) If :template is left unspecified the partial will assume the template is in a file with the same name as the partial with extension .html.eex. Update the template to make use of the profile_card helper lib/my_app/list_users.html.eex &lt;%= for user &lt;- users do %&gt; profile_card(user) &lt;% end %&gt;"},{"ref":"readme.html#reusable-layouts-and-helpers","title":"Raxx.View - Reusable Layouts and Helpers","type":"extras","doc":"Layouts can be used to define views that share layouts and possibly helpers. lib/my_app/layout.ex defmodule MyApp.Layout do use Raxx.View.Layout, layout: &quot;layout.html.eex&quot;, optional: [title: &quot;My App&quot;] def display_date(datetime = %DateTime{}) do Timex.format!(datetime, &quot;{YYYY}-0{M}-0{D}&quot;) end def user_page_link(user) do ~E&quot;&quot;&quot; &lt;a href=&quot;/users/&lt;%= user.id %&gt;&quot;&gt;&lt;%= user.name %&gt;&lt;/a&gt; &quot;&quot;&quot; end partial(:profile_card, [:user], template: &quot;profile_card.html.eex&quot;) end If :layout is left unspecified the layout will assume the template is in a file of the same name but with extension .html.eex in place of .ex or .exs. All functions defined in a layout will be available in the derived views. The list users view can be derived from our layout and use the shared helpers. lib/my_app/list_users.ex defmodule MyApp.ListUsersView do use MyApp.Layout, arguments: [:users], optional: [title: &quot;List users - My App&quot;] template: &quot;list_users.html.eex&quot;, end Variables set in :optionals for the layout can have there default value overwritten by setting them again when using the layout."}]